From: Christian Heller <c.heller@plomlompom.de>
Date: Sun, 22 Feb 2015 10:13:57 +0000 (+0100)
Subject: Server/py: Put "_tmp" temp file suffix into io_db.
X-Git-Tag: tce~505
X-Git-Url: https://plomlompom.com/repos/%7B%7Bdb.prefix%7D%7D/%7B%7B%20web_path%20%7D%7D/%7B%7Bprefix%7D%7D/static/ledger?a=commitdiff_plain;h=82e96719b4cf7105f814f72d07e0d861000c5d39;p=plomrogue

Server/py: Put "_tmp" temp file suffix into io_db.
---

diff --git a/plomrogue-server.py b/plomrogue-server.py
index e5b7c0e..568b21c 100755
--- a/plomrogue-server.py
+++ b/plomrogue-server.py
@@ -21,6 +21,7 @@ def setup_server_io(io_db):
     io_db["path_record"] = "record"
     io_db["path_save"] = "save"
     io_db["path_worldconf"] = "confserver/world"
+    io_db["tmp_suffix"] = "_tmp"
     io_db["teststring"] = str(os.getpid()) + " " + str(time.time())
     os.makedirs(io_dir, exist_ok=True)
     io_db["file_out"] = open(io_db["path_out"], "w")
@@ -43,9 +44,9 @@ def cleanup_server_io(io_db):
     helper("file_worldstate", "path_worldstate")
 
 
-def detect_atomic_leftover(path):
-    """Raise explained SystemExit if file is found at path + "_tmp"."""
-    path_tmp = path + "_tmp"
+def detect_atomic_leftover(path, tmp_suffix):
+    """Raise explained SystemExit if file is found at path + tmp_suffix."""
+    path_tmp = path + tmp_suffix
     msg = "Found file '" + path_tmp + "' that may be a leftover from an " \
           "aborted previous attempt to write '" + path + "'. Aborting until " \
           "the matter is resolved by removing it from its current path."
@@ -92,6 +93,7 @@ def obey_lines_in_file(path, name):
         line_n = line_n + 1
     file.close()
 
+
 io_db = {}
 try:
     parser = argparse.ArgumentParser()
@@ -99,8 +101,8 @@ try:
                         action='store')
     setup_server_io(io_db)
     # print("DUMMY: Run game.")
-    detect_atomic_leftover(io_db["path_save"])
-    detect_atomic_leftover(io_db["path_record"])
+    detect_atomic_leftover(io_db["path_save"], io_db["tmp_suffix"])
+    detect_atomic_leftover(io_db["path_record"], io_db["tmp_suffix"])
     opts, unknown = parser.parse_known_args()
     if None != opts.replay:
         if opts.replay < 1: